pub struct Context {
pub world: World,
pub asset_server: AssetServer,
pub game_state: GameState,
pub resources: ResourceMap,
}Fields
world: Worldasset_server: AssetServergame_state: GameStateresources: ResourceMapImplementations
Sourceimpl Context
impl Context
pub fn new(world: World, asset_server: AssetServer) -> Self
Sourcepub fn insert_resource<T: Any + Send + 'static>(&mut self, resource: T)
pub fn insert_resource<T: Any + Send + 'static>(&mut self, resource: T)
Inserts a new resource.
Sourcepub fn resource<T: Any + 'static>(&self) -> &T
pub fn resource<T: Any + 'static>(&self) -> &T
Gets an immutable reference to a resource. Panics if the resource is not found.
Sourcepub fn resource_mut<T: Any + Send + 'static>(&mut self) -> &mut T
pub fn resource_mut<T: Any + Send + 'static>(&mut self) -> &mut T
Gets a mutable reference to a resource. Panics if the resource is not found.
Sourcepub fn get_resource<T: Any + 'static>(&self) -> Option<&T>
pub fn get_resource<T: Any + 'static>(&self) -> Option<&T>
Tries to get an immutable reference to a resource. This is the method you asked for.
Sourcepub fn get_resource_mut<T: Any + Send + 'static>(&mut self) -> Option<&mut T>
pub fn get_resource_mut<T: Any + Send + 'static>(&mut self) -> Option<&mut T>
Tries to get a mutable reference to a resource.
pub fn dt(&self) -> f32