ResourceMap

Struct ResourceMap 

pub struct ResourceMap { /* private fields */ }

Implementations

Source

impl ResourceMap

pub fn new() -> Self

pub fn insert<T: Any + Send + 'static>(&mut self, resource: T)

Inserts a resource into the map. If a resource of this type already exists, it is overwritten.

T must be Any + 'static

pub fn get<T: Any + 'static>(&self) -> Option<&T>

Gets an immutable reference to a resource of type T. Returns None if the resource does not exist.

pub fn get_mut<T: Any + Send + 'static>(&mut self) -> Option<&mut T>

Gets a mutable reference to a resource of type T. Returns None if the resource does not exist.

pub fn remove<T: Any + Send + 'static>(&mut self) -> Option<T>

Removes and returns a resource of type T. Returns None if the resource does not exist.