pub struct ResourceMap { /* private fields */ }Implementations
Sourceimpl ResourceMap
impl ResourceMap
pub fn new() -> Self
Sourcepub fn insert<T: Any + Send + 'static>(&mut self, resource: T)
pub fn insert<T: Any + Send + 'static>(&mut self, resource: T)
Inserts a resource into the map. If a resource of this type already exists, it is overwritten.
T must be Any + 'static
Sourcepub fn get<T: Any + 'static>(&self) -> Option<&T>
pub fn get<T: Any + 'static>(&self) -> Option<&T>
Gets an immutable reference to a resource of type T.
Returns None if the resource does not exist.